@@ -14,5 +14,5 @@
     You should have received a copy of the GNU Affero General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
-extern char* fromnumlist(char* in);
-extern char* tonumlist(const char* in);
+extern wchar_t* fromnumlist(char* in);
+extern char* tonumlist(const wchar_t* in);
